"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OutdoorTemperatureService = void 0;
class OutdoorTemperatureService {
    constructor(platform, accessory, device) {
        this.platform = platform;
        this.device = device;
        const Characteristic = platform.Characteristic;
        // Create the outdoor temperature service
        // Implemented characteristics:
        //    CurrentTemperature
        this.service = accessory.getService(platform.Service.TemperatureSensor) ||
            accessory.addService(platform.Service.TemperatureSensor, "Outdoor");
        this.service.setCharacteristic(Characteristic.Name, "Outdoor");
        this.service.getCharacteristic(Characteristic.CurrentTemperature)
            .onGet(this.getCurrentTemperature.bind(this));
    }
    updateHomeBridgeState() {
        if (!this.device.get.valid())
            return;
        this.syncCharacteristic('CurrentTemperature', this.getCurrentTemperature());
    }
    syncCharacteristic(characteristic, value) {
        if (this.service.getCharacteristic(this.platform.Characteristic[characteristic]).value != value) {
            this.platform.log.debug(`Updating homebridge characteristics TemperatureSensor.${characteristic} => ${value}`);
            this.service.getCharacteristic(this.platform.Characteristic[characteristic]).updateValue(value);
        }
    }
    checkValid() {
        if (!this.device.get.valid())
            throw new this.platform.api.hap.HapStatusError(-70402 /* SERVICE_COMMUNICATION_FAILURE */);
    }
    ////////////////////////////////////////////////////////////////////////////////////////////////////////////
    getCurrentTemperature() {
        this.checkValid();
        return this.device.get.outdoorTemperature();
    }
}
exports.OutdoorTemperatureService = OutdoorTemperatureService;
//# sourceMappingURL=outdoor.js.map