"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OutdoorTemperatureAccessory = exports.AirconAccessory = void 0;
const aircon_1 = require("./accessories/aircon");
const dehumidifier_1 = require("./accessories/dehumidifier");
const device_1 = require("./accessories/device");
const fan_1 = require("./accessories/fan");
const outdoor_1 = require("./accessories/outdoor");
const MANUFACTURER = "Mitsubishi Heavy Industries";
const MODEL = "MH-AC-WIFI-1";
/**
 * Homebridge accessory class containing indoor aircon related services
 */
class AirconAccessory {
    constructor(device, platform, accessory, config) {
        const Characteristic = platform.Characteristic;
        device.on(device_1.EVENT_UPDATED, this.updateHomeBridgeState.bind(this));
        // set accessory information
        const service = accessory.getService(platform.Service.AccessoryInformation);
        if (service) {
            service
                .setCharacteristic(Characteristic.Identify, false)
                .setCharacteristic(Characteristic.Manufacturer, MANUFACTURER)
                .setCharacteristic(Characteristic.Model, MODEL)
                .setCharacteristic(Characteristic.SerialNumber, config.info.sn)
                .setCharacteristic(Characteristic.FirmwareRevision, config.info.fwVersion);
        }
        // Add the relavant accessories
        this.aircon = new aircon_1.AirconService(platform, accessory, device);
        this.fan = new fan_1.FanService(platform, accessory, device);
        this.dehumidifier = new dehumidifier_1.DehumidifierService(platform, accessory, device);
    }
    async updateHomeBridgeState() {
        this.aircon.updateHomeBridgeState();
        this.fan.updateHomeBridgeState();
        this.dehumidifier.updateHomeBridgeState();
    }
}
exports.AirconAccessory = AirconAccessory;
/**
 * Homebridge accessory class containing outdoor aircon related services
 */
class OutdoorTemperatureAccessory {
    constructor(device, platform, accessory, config) {
        const Characteristic = platform.Characteristic;
        device.on(device_1.EVENT_UPDATED, this.updateHomeBridgeState.bind(this));
        // set accessory information
        const service = accessory.getService(platform.Service.AccessoryInformation);
        if (service) {
            service
                .setCharacteristic(Characteristic.Name, 'Outdoor')
                .setCharacteristic(Characteristic.Identify, false)
                .setCharacteristic(Characteristic.Manufacturer, MANUFACTURER)
                .setCharacteristic(Characteristic.Model, MODEL)
                .setCharacteristic(Characteristic.SerialNumber, config.info.sn)
                .setCharacteristic(Characteristic.FirmwareRevision, config.info.fwVersion);
        }
        this.temperature = new outdoor_1.OutdoorTemperatureService(platform, accessory, device);
    }
    async updateHomeBridgeState() {
        this.temperature.updateHomeBridgeState();
    }
}
exports.OutdoorTemperatureAccessory = OutdoorTemperatureAccessory;
//# sourceMappingURL=accessory.js.map